<?php
/**
 * Widget API: WP_Widget_Top_Posters class
 * @since 1.1.1
 */

/**
 * Core class used to implement a Top Posters widget.
 *
 * @since 2.8.0
 *
 * @see WP_Widget
 */
class WP_Widget_Top_Posters extends WP_Widget {

	public function __construct() {
		$widget_ops = array(
			'classname' => 'widget_top_posts',
			'description' => __( 'Who has posted the most discussion topics.', 'discussion-board-pro' ),
			'customize_selective_refresh' => true,
		);
		parent::__construct( 'top-posters', __( 'Top Posters', 'discussion-board-pro' ), $widget_ops );
		$this->alt_option_name = 'widget_top_posts';
	}

	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Top Posters', 'discussion-board-pro' );

		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
		if ( ! $number )
			$number = 5;
		$show_count = isset( $instance['show_count'] ) ? $instance['show_count'] : false;
		$text_after_count = ( ! empty( $instance['text_after_count'] ) ) ? $instance['text_after_count'] : '';
		$text_after_count_plural = ( ! empty( $instance['text_after_count_plural'] ) ) ? $instance['text_after_count_plural'] : '';
		
		$gravatar = isset( $instance['use_gravatar'] ) ? (bool)( $instance['use_gravatar'] ) : false;
		
		// Get array of all users and the number of topics posted
		$posters = CT_DB_Pro_Profiles::top_posters();
		
		// Take the selected number
		if( ! empty( $posters ) ) {
			// Check the profiles are enabled
			$options = get_option( 'ctdb_profiles_settings' );
			// Get the top however many
			$posters = array_slice( $posters, 0, $number, true );
			?>
			<?php echo $args['before_widget']; ?>
			<?php if ( $title ) {
				echo $args['before_title'] . $title . $args['after_title'];
			}
			$classes = array(
				'recentcomments',
				'ctdb-widget-profile-list'
			);
			if( $gravatar ) {
				$classes[] = 'with-gravatar';
			}
			?>
			<ul class="<?php echo join( ' ', $classes ); ?>">
			<?php foreach ( $posters as $user_id=>$count ) { 
				// Only display users who have posted at least once
				if( $count >0 ) { ?>
					<li>
						<?php if( $gravatar ) {
							$avatar_size = 48;
							$avatar_size = apply_filters( 'ctdb_recent_replies_avatar_size', $avatar_size ); ?>
							<div class="ctdb-recent-gravatar"><?php echo get_avatar( $user_id, $avatar_size ); ?></div>
						<?php } ?>
						<div class="ctdb-widget-profile-meta">
							<?php $author_name = get_the_author_meta( 'display_name', $user_id );
							if( isset( $options['enable_profiles'] ) ) { 
								$author_url = get_author_posts_url( $user_id );
								?>
								<a href="<?php echo esc_url( $author_url ); ?>">
							<?php } ?>
								<?php echo $author_name; ?>
							<?php if( isset( $options['enable_profiles'] ) ) { ?>
								</a>
							<?php } ?>
					
							<?php if ( $show_count ) : ?>
								<br><span><?php echo $count; ?>
								<?php if( ! empty( $text_after_count ) ) {
									if( $count == 1 ) {
										echo ' ' . esc_html( $text_after_count );
									} else {
										echo ' ' . esc_html( $text_after_count_plural );
									}
								} ?>
								</span>
							<?php endif; ?>
						</div>
					</li>
				<?php }
			} ?>
			</ul>
			<?php echo $args['after_widget']; ?>
			<?php

		}
	}

	/**
	 * Handles updating the settings for the current Recent Topics widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = sanitize_text_field( $new_instance['title'] );
		$instance['number'] = (int) $new_instance['number'];
		$instance['show_count'] = isset( $new_instance['show_count'] ) ? (bool) $new_instance['show_count'] : false;
		$instance['text_after_count'] = sanitize_text_field( $new_instance['text_after_count'] );
		$instance['text_after_count_plural'] = sanitize_text_field( $new_instance['text_after_count_plural'] );
		$instance['use_gravatar'] = $new_instance['use_gravatar'];
		return $instance;
	}

	/**
	 * Outputs the settings form for the Recent Topics widget.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		$show_count = isset( $instance['show_count'] ) ? (bool) $instance['show_count'] : false;
		$text_after_count = isset( $instance['text_after_count'] ) ? esc_attr( $instance['text_after_count'] ) : __( 'topic posted', 'discussion-board-pro' );
		$text_after_count_plural = isset( $instance['text_after_count_plural'] ) ? esc_attr( $instance['text_after_count_plural'] ) : __( 'topics posted', 'discussion-board-pro' );
		$gravatar = isset( $instance['use_gravatar'] ) ? (bool)( $instance['use_gravatar'] ) : false;
?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'discussion-board-pro' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of posters to show:', 'discussion-board-pro' ); ?></label>
		<input class="tiny-text" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="number" step="1" min="1" value="<?php echo $number; ?>" size="3" /></p>

		<p><input class="checkbox" type="checkbox"<?php checked( $show_count ); ?> id="<?php echo $this->get_field_id( 'show_count' ); ?>" name="<?php echo $this->get_field_name( 'show_count' ); ?>" />
		<label for="<?php echo $this->get_field_id( 'show_count' ); ?>"><?php _e( 'Display topic count?', 'discussion-board-pro' ); ?></label></p>
		
		<p><label for="<?php echo $this->get_field_id( 'text_after_count' ); ?>"><?php _e( 'Text after count (singular):', 'discussion-board-pro' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'text_after_count' ); ?>" name="<?php echo $this->get_field_name( 'text_after_count' ); ?>" type="text" value="<?php echo $text_after_count; ?>" /></p>
		
		<p><label for="<?php echo $this->get_field_id( 'text_after_count_plural' ); ?>"><?php _e( 'Text after count (plural):', 'discussion-board-pro' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'text_after_count_plural' ); ?>" name="<?php echo $this->get_field_name( 'text_after_count_plural' ); ?>" type="text" value="<?php echo $text_after_count_plural; ?>" /></p>
		
		<p><input class="checkbox" type="checkbox" <?php checked( $gravatar ); ?> id="<?php echo $this->get_field_id( 'use_gravatar' ); ?>" name="<?php echo $this->get_field_name( 'use_gravatar' ); ?>" />
		<label for="<?php echo $this->get_field_id( 'use_gravatar' ); ?>"><?php _e( 'Display gravatar?' ); ?></label></p>
	<?php }
}
